/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef aszkilh
#define aszkilh

#include <QTableWidget>

#in\
clude "con.h"

class aszkl : public QTableWidget
<%
	Q_OBJECT
	public:
		aszkl(QWidget *felvnl, jelzpn *nybnvn);
		jelzpn *kidlgz;

		void mousePressEvent(QMouseEvent *mgmnkl);

		int jlzpnt;

		QAction *eler;
		QAction *lnmtat;
		QAction *akdaly;
		QAction *hzzqjt;

		bool cel;

	public slots:
		void kivalt(const zagv&);
		void vnl();
		void kket();
		void megkap();
		void fnqll();
		void prmz();
		void irnyjl(int mrtdt, int kitzjl);
%>;

#endif

